import React, { useState, useEffect } from 'react';
import { Route, Redirect, RouteProps } from 'react-router-dom';
import { AuthRoutes } from 'api/routes';
import { isAuthenticated } from 'api/isAuthenticated';
import { CircularProgress } from '@material-ui/core';

/**
 *
 * */
type Props = {
  Component: React.FC<RouteProps>;
  path: string;
};

/**
 * Wrapper for Route that basing on if the user is authenticated,
 * redirects to:
 * - Entry point of the private route (the homepage);
 * - Login page.
 */

/* eslint-disable react/jsx-props-no-spreading */
export const RestrictedRoute = ({ Component, path }: Props): JSX.Element => {
  const [isAuth, setIsAuth] = useState<boolean>(false);
  const [isLoading, setLoading] = useState<boolean>(false);

  useEffect(() => {
    let isMounted = true;

    isAuthenticated().then((state) => {
      if (isMounted) {
        setIsAuth(state);
        setLoading(true);
      }
    });

    return () => {
      isMounted = false;
    };
  }, [isLoading]);

  return !isLoading ? (
    <CircularProgress />
  ) : (
    <Route
      path={path}
      render={(props: RouteProps) =>
        !isAuth ? (
          // Redirect to component.
          <Component {...props} />
        ) : (
          // Redirect to homepage.
          <Redirect
            to={{ pathname: `${AuthRoutes.dashboard}${AuthRoutes.home}` }}
          />
        )
      }
    />
  );
};
